==> haskell-system-fileio-0.3.16.3-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: system-fileio
version: 0.3.16.3
id: system-fileio-0.3.16.3-KZP3u31C9MzFt3sVRftkO4
key: system-fileio-0.3.16.3-KZP3u31C9MzFt3sVRftkO4
license: MIT
maintainer: FP Complete <michael@fpcomplete.com>
author: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://github.com/fpco/haskell-filesystem
synopsis: Consistent filesystem interaction across GHC versions (deprecated)
description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx
category: System
abi: caea030ae26f09de2c651de8ccc9ab55
exposed: True
exposed-modules:
    Filesystem
import-dirs: /usr/lib/ghc-8.4.3/site-local/system-fileio-0.3.16.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/system-fileio-0.3.16.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/system-fileio-0.3.16.3
hs-libraries: HSsystem-fileio-0.3.16.3-KZP3u31C9MzFt3sVRftkO4
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4 text-1.2.3.0
    time-1.8.0.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4=14adf804eb2ee22bef25db71be916c66
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock
haddock-html: /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-system-fileio-0.3.16.4-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: system-fileio
version: 0.3.16.4
id: system-fileio-0.3.16.4-9sx9wM2ewcAGE6Edeaomm
key: system-fileio-0.3.16.4-9sx9wM2ewcAGE6Edeaomm
license: MIT
maintainer: FP Complete <michael@fpcomplete.com>
author: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://github.com/fpco/haskell-filesystem
synopsis: Consistent filesystem interaction across GHC versions (deprecated)
description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx
category: System
abi: 37c2c7ce65c654ffd5891288a911d53a
exposed: True
exposed-modules:
    Filesystem
import-dirs: /usr/lib/ghc-8.4.3/site-local/system-fileio-0.3.16.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/system-fileio-0.3.16.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/system-fileio-0.3.16.4
hs-libraries: HSsystem-fileio-0.3.16.4-9sx9wM2ewcAGE6Edeaomm
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4 text-1.2.3.0
    time-1.8.0.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4=14adf804eb2ee22bef25db71be916c66
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock
haddock-html: /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
